﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Infragistics.Controls.Schedules;

namespace XamScheduleSilverlight
{
    public class ScheduleData
    {
        private ObservableCollection<Resource> _resources = new ObservableCollection<Resource>();
        private ObservableCollection<ResourceCalendar> _resourceCalendars = new ObservableCollection<ResourceCalendar>();
        private ObservableCollection<Appointment> _appointments = new ObservableCollection<Appointment>();
        private ObservableCollection<Task> _tasks = new ObservableCollection<Task>();
        private ObservableCollection<Journal> _journals = new ObservableCollection<Journal>();

        public ObservableCollection<Resource> Resources
        {
            get { return _resources; }
            set { _resources = value; }
        }

        public ObservableCollection<ResourceCalendar> ResourceCalendars
        {
            get { return _resourceCalendars; }
            set { _resourceCalendars = value; }
        }

        public ObservableCollection<Appointment> Appointments
        {
            get { return _appointments; }
            set { _appointments = value; }
        }

        public ObservableCollection<Task> Tasks
        {
            get { return _tasks; }
            set { _tasks = value; }
        }

        public ObservableCollection<Journal> Journals
        {
            get { return _journals; }
            set { _journals = value; }
        }

        public ScheduleData()
        {
            InitializeData();
        }

        private void InitializeData()
        {
            #region Initialize users

            Resource user1 = new Resource { Name = "User 1", EmailAddress = "user1@info.com", Description = "User1Description", Id = "user1" };
            Resource user2 = new Resource { Name = "User 2", EmailAddress = "user2@info.com", Description = "User2Description", Id = "user2" };
            this.Resources.Add(user1);
            this.Resources.Add(user2);

            #endregion // Initialize users

            #region Initialize calendars

            ResourceCalendar user1Calendar1 = new ResourceCalendar { Name = "User1 Calendar1", OwningResourceId = "user1", Id = "user1Calendar1" };
            ResourceCalendar user1Calendar2 = new ResourceCalendar { Name = "User1 Calendar2", OwningResourceId = "user1", Id = "user1Calendar2" };
            ResourceCalendar user2Calendar1 = new ResourceCalendar { Name = "User2 Calendar1", OwningResourceId = "user2", Id = "user2Calendar1" };
            this.ResourceCalendars.Add(user1Calendar1);
            this.ResourceCalendars.Add(user1Calendar2);
            this.ResourceCalendars.Add(user2Calendar1);

            #endregion //Initialize calendars

            #region InitializeAppointments

            Appointment user1Appointment1 = new Appointment { Id = "user1Appointment1", OwningResourceId = "user1", OwningCalendarId = "user1Calendar1" };
            user1Appointment1.Subject = "User1 First Appointment";
            user1Appointment1.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);
            user1Appointment1.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);

            Appointment user1Appointment2 = new Appointment { Id = "user1Appointment2", OwningResourceId = "user1", OwningCalendarId = "user1Calendar1" };
            user1Appointment2.Subject = "User1 Second Appointment";
            user1Appointment2.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1Appointment2.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            Appointment user1Appointment3 = new Appointment { Id = "user1Appointment3", OwningResourceId = "user1", OwningCalendarId = "user1Calendar1" };
            user1Appointment3.Subject = "User1 Third Appointment";
            user1Appointment3.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1Appointment3.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            Appointment user1Appointment4 = new Appointment { Id = "user1Appointment4", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1Appointment4.Subject = "User1 Fourth Appointment";
            user1Appointment4.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1Appointment4.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            Appointment user1Appointment5 = new Appointment { Id = "user1Appointment5", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1Appointment5.Subject = "User1 Fifth Appointment";
            user1Appointment5.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user1Appointment5.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            Appointment user1Appointment6 = new Appointment { Id = "user1Appointment6", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1Appointment6.Subject = "User1 Sixth Appointment";
            user1Appointment6.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);
            user1Appointment6.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);

            Appointment user1Appointment7 = new Appointment { Id = "user1Appointment7", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1Appointment7.Subject = "User1 Seventh Appointment";
            user1Appointment7.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.AddDays(1).Day, 10, 0, 0);
            user1Appointment7.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.AddDays(1).Day, 15, 0, 0);

            Appointment user1Appointment8 = new Appointment { Id = "user1Appointment8", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1Appointment8.Subject = "User1 Eight Appointment";
            user1Appointment8.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.AddDays(2).Day, 9, 0, 0);
            user1Appointment8.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.AddDays(2).Day, 13, 0, 0);

            Appointment user2Appointment1 = new Appointment { Id = "user2Appointment1", OwningResourceId = "user2", OwningCalendarId = "user2Calendar1" };
            user2Appointment1.Subject = "User2 First Appointment";
            user2Appointment1.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);
            user2Appointment1.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);

            Appointment user2Appointment2 = new Appointment { Id = "user2Appointment2", OwningResourceId = "user2", OwningCalendarId = "user2Calendar1" };
            user2Appointment2.Subject = "User2 Second Appointment";
            user2Appointment2.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 11, 0, 0);
            user2Appointment2.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 12, 0, 0);

            this.Appointments.Add(user1Appointment1);
            this.Appointments.Add(user1Appointment2);
            this.Appointments.Add(user1Appointment3);
            this.Appointments.Add(user1Appointment4);
            this.Appointments.Add(user1Appointment5);
            this.Appointments.Add(user1Appointment6);
            this.Appointments.Add(user1Appointment7);
            this.Appointments.Add(user1Appointment8);
            this.Appointments.Add(user2Appointment1);
            this.Appointments.Add(user2Appointment2);

            #endregion //InitializeAppointments

            #region Initialize tasks

            Task user1Task1 = new Task { Id = "user1Task1", OwningResourceId = "user1", OwningCalendarId = "user1Calendar1" };
            user1Task1.Subject = "User1 First Task";
            user1Task1.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 8, 0, 0);
            user1Task1.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);

            Task user1Task2 = new Task { Id = "user1Task2", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1Task2.Subject = "User1 Second Task";
            user1Task2.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);
            user1Task2.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 10, 0, 0);

            Task user2Task1 = new Task { Id = "user2Task1", OwningResourceId = "user2", OwningCalendarId = "user2Calendar1" };
            user2Task1.Subject = "User2 First Task";
            user2Task1.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);
            user2Task1.End = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 10, 0, 0);

            this.Tasks.Add(user1Task1);
            this.Tasks.Add(user1Task2);
            this.Tasks.Add(user2Task1);

            #endregion // Initialize tasks

            #region Initialize journals

            Journal user1Journal1 = new Journal { Id = "user1Journal1", OwningResourceId = "user1", OwningCalendarId = "user1Calendar1" };
            user1Journal1.Subject = "User1 First Journal";
            user1Journal1.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 8, 0, 0);

            Journal user1Journal2 = new Journal { Id = "user1Journal2", OwningResourceId = "user1", OwningCalendarId = "user1Calendar2" };
            user1Journal2.Subject = "User1 Second Journal";
            user1Journal2.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);

            Journal user2Journal1 = new Journal { Id = "user2Journal1", OwningResourceId = "user2", OwningCalendarId = "user2Calendar1" };
            user2Journal1.Subject = "User2 First Journal";
            user2Journal1.Start = new DateTime(DateTime.Now.Year, DateTime.Now.Month, DateTime.Now.Day, 9, 0, 0);

            this.Journals.Add(user1Journal1);
            this.Journals.Add(user1Journal2);
            this.Journals.Add(user2Journal1);

            #endregion // Initialize journals
        }
    }
}
